sqlobject.tests.test_new_joins module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_new_joins module

class `sqlobject.tests.test_new_joins.` `AddressJNew`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `byZip`(val, connection=None)
  `j` = address_j_new
  `personJs`
  `q` = address_j_new
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_new_joins.AddressJNew`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'address_j_new'
  property `zip`

class `sqlobject.tests.test_new_joins.` `AddressJNew2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = address_j_new2
  property `personJNew2`
  property `personJNew2ID`
  property `plus4`
  `q` = address_j_new2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `defaultOrder` = ['-zip', 'plus4']
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_new_joins.AddressJNew2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'address_j_new2'
  property `zip`

class `sqlobject.tests.test_new_joins.` `AddressJNew3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = address_j_new3
  property `personJNew3`
  property `personJNew3ID`
  `q` = address_j_new3
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_new_joins.AddressJNew3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'address_j_new3'
  property `zip`

class `sqlobject.tests.test_new_joins.` `ExplicitJoiningSONew`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `foo`
  `j` = explicit_joining_so_new
  `q` = explicit_joining_so_new
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_new_joins.ExplicitJoiningSONew`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'explicit_joining_so_new'

class `sqlobject.tests.test_new_joins.` `ImplicitJoiningSONew`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `foo`
  `j` = implicit_joining_so_new
  `q` = implicit_joining_so_new
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_new_joins.ImplicitJoiningSONew`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'implicit_joining_so_new'

class `sqlobject.tests.test_new_joins.` `PersonJNew`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addressJs`
  classmethod `byName`(val, connection=None)
  `j` = person_j_new
  property `name`
  `q` = person_j_new
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_new_joins.PersonJNew`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'person_j_new'

class `sqlobject.tests.test_new_joins.` `PersonJNew2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addressJ2s`
  classmethod `byName`(val, connection=None)
  `j` = person_j_new2
  property `name`
  `q` = person_j_new2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_new_joins.PersonJNew2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'person_j_new2'

class `sqlobject.tests.test_new_joins.` `PersonJNew3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `addressJNew3s`
  classmethod `byName`(val, connection=None)
  `j` = person_j_new3
  property `name`
  `q` = person_j_new3
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_new_joins.PersonJNew3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'person_j_new3'

class `sqlobject.tests.test_new_joins.` `TestJoin`

  Bases: `object`

  `assertNamesEqual`(people, dest)
  `assertZipsEqual`(zips, dest)
  `setup_method`(meth)
  `test_join`()
  `test_joinAttributeWithUnderscores`()

class `sqlobject.tests.test_new_joins.` `TestJoin2`

  Bases: `object`

  `setup_method`(meth)
  `test_basic`()
  `test_defaultOrder`()

class `sqlobject.tests.test_new_joins.` `TestJoin3`

  Bases: `object`

  `setup_method`(meth)
  `test_accessors`()